@@ -7,7 +7,7 @@ use warnings;
 
 use base 'Type::Library';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 
@@ -44,6 +44,14 @@ L<Type::Library> type library.
 
 =cut
 
+=head1 INHERITS
+
+This package inherits behaviors from:
+
+L<Type::Library>
+
+=cut
+
 =head1 LIBRARIES
 
 This package uses type constraints from:
